| pesa | R Documentation |
A processed dataset of Argos satellite telemetry locations for male pectoral sandpipers, Calidris melanotos, tracked during the Arctic breeding season.
pesa
A data.table with 129536 rows and 7 variables.
If data.table is installed when the dataset is loaded, pesa is returned
as a keyed data.table.
Individual male identifier.
Timestamp of the Argos location fix, as POSIXct in UTC.
Latitude in decimal degrees.
Longitude in decimal degrees.
Residency site identifier. Non-site id points are NA
Argos location class.
Use-sites were identified in the original analysis using
density-based spatial clustering (DBSCAN). This dataset provides a useful
benchmark because the original DBSCAN parameters, \epsilon and
MinPts, were tuned using a subset of males for which the expected
classification was known. Additionally all identified use-sites were
also checked visually, with a small number of manual corrections
applied where needed. See Kempenaers and Valcu (2017)
\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1038/nature20813")} for details.
Kempenaers, B. and Valcu, M. (2017). Breeding site sampling across the Arctic by individual males of a polygynous shorebird. Nature. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1038/nature20813")}
Data and analysis code were made available at \Sexpr[results=rd]{tools:::Rd_expr_doi("10.17605/OSF.IO/VX2MK")} under an Open Data Commons Open Database License.
Kempenaers, B. and Valcu, M. (2017). Breeding site sampling across the Arctic by individual males of a polygynous shorebird. Nature. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1038/nature20813")}
data(pesa)
head(pesa)
dim(pesa)
names(pesa)
# Number of locations per bird
table(pesa$id)
# Time span covered by the dataset
range(pesa$time)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.